/*
 * Name:    mp_amplifier.c
 *
 * Purpose: Python module interface to generic MX amplifier functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "Python.h"

#include "mx_util.h"
#include "mx_record.h"
#include "mx_amplifier.h"
#include "mx_handle.h"
#include "mp.h"

MX_EXPORT PyObject *
MpPrivate_amplifier_get_gain_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	double gain;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_amplifier_get_gain( record, &gain );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "d", gain );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_amplifier_set_gain_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	double gain;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ld", &handle, &gain );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_amplifier_set_gain( record, gain );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_amplifier_get_offset_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	double offset;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_amplifier_get_offset( record, &offset );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "d", offset );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_amplifier_set_offset_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	double offset;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ld", &handle, &offset );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_amplifier_set_offset( record, offset );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_amplifier_get_time_constant_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	double time_constant;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_amplifier_get_time_constant( record, &time_constant );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "d", time_constant );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_amplifier_set_time_constant_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	double time_constant;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ld", &handle, &time_constant );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_amplifier_set_time_constant( record, time_constant );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

